@@ -1,8 +1,24 @@
+#' @importFrom tidyr unite
+
 plot_grouped <- function(df, value, series, group, plot_type, 
                          col_palette, text_labels, ylab){
   
-  df[group] <- as.character(unlist(df[group]))
+  # get group names
+  grp_attr <- attr(df, 'groups')
+  ngroups  <- ncol(grp_attr) - 1
+  grp_cols <- df %>% 
+    ungroup %>%
+    select(1:ngroups) %>% 
+    mutate_all(as.character) %>%
+    unite(group, 1:ngroups)
+  # replace grouping columns with single column
+  df <- bind_cols(grp_cols,     
+                  df %>%
+                    ungroup %>%
+                    select(-(1:ngroups)))
+  group <- 'group'
   df[is.na(df[group]), group] <- 'NA'
+  
   if(plot_type == "line"){
     n_df  <- length(unlist(unique(df[series])))
     vcols <- c("gray50", user_colours(9, col_palette)[9])
@@ -10,7 +26,8 @@ plot_grouped <- function(df, value, series, group, plot_type,
     plt <- df %>%
       ggplot(aes_string(x = group, y = value, colour = series, 
                         group = series)) +
-      geom_blank() + theme_bw() + 
+      geom_blank() + 
+      theme_bw() + 
       geom_hline(yintercept = 0, alpha = 0.5, linetype = "dashed") + 
       theme(panel.border = element_blank(), 
             panel.grid.major = element_blank(), 
@@ -27,7 +44,8 @@ plot_grouped <- function(df, value, series, group, plot_type,
     plt <- df %>%
       ggplot(aes_string(x = series, y = value, fill = group, 
                         group = group, label = group)) +
-      geom_blank() + theme_bw() + 
+      geom_blank() + 
+      theme_bw() + 
       theme(panel.border = element_blank(), 
             panel.grid.major = element_blank(), 
             axis.text.x = element_text(angle = 45)) +
@@ -35,17 +53,18 @@ plot_grouped <- function(df, value, series, group, plot_type,
       scale_fill_manual(values = bcols) +
       guides(fill = FALSE) + 
       labs(y = ylab, x = "")
-    if(text_labels & !all(df[value] == 0)){
-      plt <- plt + geom_bar_text(position = 'dodge',
-                                 color = "white",
-                                 stat = 'identity',
-                                 angle = 90,
-                                 grow = TRUE,
-                                 reflow = TRUE,
-                                 place = "top",
-                                 min.size = 3, 
-                                 na.rm = TRUE)
-    }
+    # if(text_labels & !all(df[value] == 0)){
+    #   plt <- plt + 
+    #     geom_bar_text(position = 'dodge',
+    #                   color = "white",
+    #                   stat = 'identity',
+    #                   angle = 90,
+    #                   grow = TRUE,
+    #                   reflow = TRUE,
+    #                   place = "top",
+    #                   min.size = 3, 
+    #                   na.rm = TRUE)
+    # }
   }
   return(plt)
 }
\ No newline at end of file
